package Bundle::Theory;

# $Id: Meta.pm 3331 2008-01-22 19:24:49Z theory $

our $VERSION = '1.02';

1;
__END__

=begin comment

Fake-out Module::Build. Delete if it ever changes to support =head1 headers
other than all uppercase.

=head1 NAME

Bundle::Theory - A bundle to install all Theory's favorite modules

=end comment

=head1 Name

Bundle::Theory - A bundle to install all Theory's favorite modules

=head1 Synopsis

  perl -MCPAN -e 'install Bundle::Theory'

=head1 Description

This bundle contains all of Theory's most-used CPAN modules. These are
essentials whenever I he builds a new system.

=head1 CONTENTS

Term::ReadLine::Perl

Cwd

Bundle::CPAN

Bundle::libnet

Bundle::LWP

Module::Build

Module::Install

ExtUtils::MakeMaker

CPANPLUS

CPAN::Reporter

Test::Reporter

CPAN::SQLite

YAML

DBI

DBD::SQLite

DBD::Pg

App::Info

Class::Delegator

Data::Types

Class::Meta

Class::Meta::Express

Encode::ZapCP1252

Exception::Class::DBI

FSA::Rules

Lingua::Strfname

Params::CallbackRequest

MasonX::Interp::WithCallbacks

Module::Build::JSAN

SVN::Notify

Text::Diff::HTML

Text::WordDiff

Time::Piece::ISO

Widget::Meta

Text::Password::Pronounceable

XMLRPC::Lite

Time::HiRes

Cache::Cache

Cache::Mmap

CHI

Cache::Memcached

Digest::MD5

Digest::SHA1

URI

HTML::Parser

MIME::Base64

MIME::Tools

MIME::Types

MIME::Lite

Bundle::Email

Email::Valid

Module::Starter

Image::Info

Params::Validate

DB_File

XML::Parser

XML::Simple

XML::Generator

XML::LibXML

XML::Writer

XML::SAX

IO::Stringy

File::Path

File::Temp

Text::LevenshteinXS

Locale::Maketext

DateTime

DateTime::TimeZone

DateTime::Incomplete

DateTime::Format::Strptime

Encode

Event

Term::ReadPassword

List::Util

List::MoreUtils

URI::Escape

Iterator

Iterator::Util

aliased

Array::AsHash

Class::BuildMethods

Class::Trait

Data::Dumper::Names

Data::Dumper

Perl::Critic

HOP::Stream

HOP::Lexer

HOP::Parser

TAP::Parser

Parse::RecDescent

Pod::Simple

TAP::Harness

Test::Harness

Test::More

Test::MockModule

Test::Class

Test::Pod

Test::Coverage

Test::JSON

Test::XML

Test::Output

Test::Deep

Test::Differences

Test::Differences

Test::Exception

Test::File

Test::File::Contents

Test::NoWarnings

Test::Data::Array

Test::Number::Delta

Test::Trap

Test::Perl::Critic

Exporter::Tidy

File::Find::Rule

JSON::Syck

Lingua::EN::Inflect

Regexp::Common

App::Cmd

version

Net::SSLeay

Net::LDAP

CGI

HTML::Mason

HTML::Template

Template

Imager

Image::Info

IO::All

IO::Socket::SSL

Net::Daemon

Net::FTP::Server

Text::Iconv

CPAN::Mini

Data::GUID

Class::MOP

Return::Value

Sub::Exporter

Moose

=head1 Author

=begin comment

Fake-out Module::Build. Delete if it ever changes to support =head1 headers
other than all uppercase.

=head1 AUTHOR

=end comment

David E. Wheeler <david@kineticode.com>

=head1 License

This module is free software; you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut
